package cn.com.infosec.asn1.tsp;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERBoolean;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.x509.X509Extensions;

public class TimeStampReq extends ASN1Encodable {
   DERInteger version;
   MessageImprint messageImprint;
   DERObjectIdentifier tsaPolicy;
   DERInteger nonce;
   DERBoolean certReq;
   X509Extensions extensions;

   public static TimeStampReq getInstance(Object o) {
      if (o != null && !(o instanceof TimeStampReq)) {
         if (o instanceof ASN1Sequence) {
            return new TimeStampReq((ASN1Sequence)o);
         } else {
            throw new IllegalArgumentException("Unknown object in 'TimeStampReq' factory : " + o.getClass().getName() + ".");
         }
      } else {
         return (TimeStampReq)o;
      }
   }

   public TimeStampReq(ASN1Sequence seq) {
      int var2 = seq.size();
      this.version = DERInteger.getInstance(seq.getObjectAt(0));
      this.messageImprint = MessageImprint.getInstance(seq.getObjectAt(1));

      for(int var3 = 2; var3 < var2; ++var3) {
         if (seq.getObjectAt(var3) instanceof DERObjectIdentifier) {
            this.tsaPolicy = DERObjectIdentifier.getInstance(seq.getObjectAt(var3));
         } else if (seq.getObjectAt(var3) instanceof DERInteger) {
            this.nonce = DERInteger.getInstance(seq.getObjectAt(var3));
         } else if (seq.getObjectAt(var3) instanceof DERBoolean) {
            this.certReq = DERBoolean.getInstance(seq.getObjectAt(var3));
         } else {
            ASN1TaggedObject var4;
            if (seq.getObjectAt(var3) instanceof ASN1TaggedObject && (var4 = (ASN1TaggedObject)seq.getObjectAt(var3)).getTagNo() == 0) {
               this.extensions = X509Extensions.getInstance(var4, false);
            }
         }
      }

   }

   public TimeStampReq(MessageImprint messageImprint, DERObjectIdentifier tsaPolicy, DERInteger nonce, DERBoolean certReq, X509Extensions extensions) {
      TimeStampReq var10000 = this;
      TimeStampReq var10001 = this;
      TimeStampReq var10002 = this;
      TimeStampReq var10003 = this;
      TimeStampReq var10004 = this;
      TimeStampReq var10005 = this;
      super();
      DERInteger var6;
      var6 = new DERInteger.<init>(1);
      var10005.version = var6;
      var10004.messageImprint = messageImprint;
      var10003.tsaPolicy = tsaPolicy;
      var10002.nonce = nonce;
      var10001.certReq = certReq;
      var10000.extensions = extensions;
   }

   public DERInteger getVersion() {
      return this.version;
   }

   public MessageImprint getMessageImprint() {
      return this.messageImprint;
   }

   public DERObjectIdentifier getReqPolicy() {
      return this.tsaPolicy;
   }

   public DERInteger getNonce() {
      return this.nonce;
   }

   public DERBoolean getCertReq() {
      return this.certReq;
   }

   public X509Extensions getExtensions() {
      return this.extensions;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.version);
      var10001.add(this.messageImprint);
      DERObjectIdentifier var2;
      if ((var2 = this.tsaPolicy) != null) {
         var1.add(var2);
      }

      DERInteger var4;
      if ((var4 = this.nonce) != null) {
         var1.add(var4);
      }

      DERBoolean var5;
      if ((var5 = this.certReq) != null && var5.isTrue()) {
         var1.add(this.certReq);
      }

      X509Extensions var3;
      if ((var3 = this.extensions) != null) {
         DERTaggedObject var6;
         var6 = new DERTaggedObject.<init>(false, 0, var3);
         var1.add(var6);
      }

      return new DERSequence(var1);
   }
}
